@@ -2,15 +2,18 @@
 
 import argparse
 import os
+import urllib
 from typing import (
     Any,
     AnyStr,
+    Callable,
     Dict,
     List,
     MutableMapping,
     MutableSequence,
     Optional,
     Sequence,
+    Type,
     Union,
     cast,
 )
@@ -37,6 +40,14 @@ def arg_parser() -> argparse.ArgumentParser:
         help="Output directory. The default is the current directory.",
     )
 
+    parser.add_argument(
+        "--log-dir",
+        type=str,
+        default="",
+        help="Log your tools stdout/stderr to this location outside of container "
+        "This will only log stdout/stderr if you specify stdout/stderr in their respective fields or capture it as an output",
+    )
+
     parser.add_argument(
         "--parallel",
         action="store_true",
@@ -467,14 +478,18 @@ def arg_parser() -> argparse.ArgumentParser:
     conda_dependencies = argparse.SUPPRESS
 
     if SOFTWARE_REQUIREMENTS_ENABLED:
-        dependency_resolvers_configuration_help = "Dependency resolver "
-        "configuration file describing how to adapt 'SoftwareRequirement' "
-        "packages to current system."
+        dependency_resolvers_configuration_help = (
+            "Dependency resolver "
+            "configuration file describing how to adapt 'SoftwareRequirement' "
+            "packages to current system."
+        )
         dependencies_directory_help = (
-            "Defaut root directory used by dependency resolvers configuration."
+            "Default root directory used by dependency resolvers configuration."
+        )
+        use_biocontainers_help = (
+            "Use biocontainers for tools without an "
+            "explicitly annotated Docker container."
         )
-        use_biocontainers_help = "Use biocontainers for tools without an "
-        "explicitly annotated Docker container."
         conda_dependencies = (
             "Short cut to use Conda to resolve 'SoftwareRequirement' packages."
         )
@@ -716,18 +731,26 @@ class FSAction(argparse.Action):
     objclass = None  # type: str
 
     def __init__(
-        self, option_strings: List[str], dest: str, nargs: Any = None, **kwargs: Any
+        self,
+        option_strings: List[str],
+        dest: str,
+        nargs: Any = None,
+        urljoin: Callable[[str, str], str] = urllib.parse.urljoin,
+        base_uri: str = "",
+        **kwargs: Any,
     ) -> None:
         """Fail if nargs is used."""
         if nargs is not None:
             raise ValueError("nargs not allowed")
+        self.urljoin = urljoin
+        self.base_uri = base_uri
         super().__init__(option_strings, dest, **kwargs)
 
     def __call__(
         self,
         parser: argparse.ArgumentParser,
         namespace: argparse.Namespace,
-        values: Union[AnyStr, Sequence[Any], None],
+        values: Union[str, Sequence[Any], None],
         option_string: Optional[str] = None,
     ) -> None:
         setattr(
@@ -735,7 +758,7 @@ class FSAction(argparse.Action):
             self.dest,
             {
                 "class": self.objclass,
-                "location": file_uri(str(os.path.abspath(cast(AnyStr, values)))),
+                "location": self.urljoin(self.base_uri, cast(str, values)),
             },
         )
 
@@ -744,18 +767,26 @@ class FSAppendAction(argparse.Action):
     objclass = None  # type: str
 
     def __init__(
-        self, option_strings: List[str], dest: str, nargs: Any = None, **kwargs: Any
+        self,
+        option_strings: List[str],
+        dest: str,
+        nargs: Any = None,
+        urljoin: Callable[[str, str], str] = urllib.parse.urljoin,
+        base_uri: str = "",
+        **kwargs: Any,
     ) -> None:
         """Initialize."""
         if nargs is not None:
             raise ValueError("nargs not allowed")
+        self.urljoin = urljoin
+        self.base_uri = base_uri
         super().__init__(option_strings, dest, **kwargs)
 
     def __call__(
         self,
         parser: argparse.ArgumentParser,
         namespace: argparse.Namespace,
-        values: Union[AnyStr, Sequence[Any], None],
+        values: Union[str, Sequence[Any], None],
         option_string: Optional[str] = None,
     ) -> None:
         g = getattr(namespace, self.dest)
@@ -765,7 +796,7 @@ class FSAppendAction(argparse.Action):
         g.append(
             {
                 "class": self.objclass,
-                "location": file_uri(str(os.path.abspath(cast(AnyStr, values)))),
+                "location": self.urljoin(self.base_uri, cast(str, values)),
             }
         )
 
@@ -794,6 +825,8 @@ def add_argument(
     description: str = "",
     default: Any = None,
     input_required: bool = True,
+    urljoin: Callable[[str, str], str] = urllib.parse.urljoin,
+    base_uri: str = "",
 ) -> None:
     if len(name) == 1:
         flag = "-"
@@ -804,27 +837,32 @@ def add_argument(
     # parameter required.
     required = default is None and input_required
     if isinstance(inptype, MutableSequence):
-        if inptype[0] == "null":
+        if len(inptype) == 1:
+            inptype = inptype[0]
+        elif len(inptype) == 2 and inptype[0] == "null":
             required = False
-            if len(inptype) == 2:
-                inptype = inptype[1]
-            else:
-                _logger.debug("Can't make command line argument from %s", inptype)
-                return None
+            inptype = inptype[1]
+        elif len(inptype) == 2 and inptype[1] == "null":
+            required = False
+            inptype = inptype[0]
+        else:
+            _logger.debug("Can't make command line argument from %s", inptype)
+            return None
 
     ahelp = description.replace("%", "%%")
-    action = None  # type: Optional[Union[argparse.Action, str]]
+    action = None  # type: Optional[Union[Type[argparse.Action], str]]
     atype = None  # type: Any
+    typekw = {}  # type: Dict[str, Any]
 
     if inptype == "File":
-        action = cast(argparse.Action, FileAction)
+        action = FileAction
     elif inptype == "Directory":
-        action = cast(argparse.Action, DirectoryAction)
+        action = DirectoryAction
     elif isinstance(inptype, MutableMapping) and inptype["type"] == "array":
         if inptype["items"] == "File":
-            action = cast(argparse.Action, FileAppendAction)
+            action = FileAppendAction
         elif inptype["items"] == "Directory":
-            action = cast(argparse.Action, DirectoryAppendAction)
+            action = DirectoryAppendAction
         else:
             action = "append"
     elif isinstance(inptype, MutableMapping) and inptype["type"] == "enum":
@@ -835,12 +873,24 @@ def add_argument(
             fieldname = name + "." + shortname(field["name"])
             fieldtype = field["type"]
             fielddescription = field.get("doc", "")
-            add_argument(toolparser, fieldname, fieldtype, records, fielddescription)
+            add_argument(
+                toolparser,
+                fieldname,
+                fieldtype,
+                records,
+                fielddescription,
+                default=default.get(shortname(field["name"]), None)
+                if default
+                else None,
+                input_required=required,
+            )
         return
     elif inptype == "string":
         atype = str
     elif inptype == "int":
         atype = int
+    elif inptype == "long":
+        atype = int
     elif inptype == "double":
         atype = float
     elif inptype == "float":
@@ -851,10 +901,12 @@ def add_argument(
         _logger.debug("Can't make command line argument from %s", inptype)
         return None
 
+    if action in (FileAction, DirectoryAction, FileAppendAction, DirectoryAppendAction):
+        typekw["urljoin"] = urljoin
+        typekw["base_uri"] = base_uri
+
     if inptype != "boolean":
-        typekw = {"type": atype}
-    else:
-        typekw = {}
+        typekw["type"] = atype
 
     toolparser.add_argument(
         flag + name,
@@ -862,7 +914,7 @@ def add_argument(
         help=ahelp,
         action=action,  # type: ignore
         default=default,
-        **typekw
+        **typekw,
     )
 
 
@@ -872,6 +924,8 @@ def generate_parser(
     namemap: Dict[str, str],
     records: List[str],
     input_required: bool = True,
+    urljoin: Callable[[str, str], str] = urllib.parse.urljoin,
+    base_uri: str = "",
 ) -> argparse.ArgumentParser:
     toolparser.description = tool.tool.get("doc", None)
     toolparser.add_argument("job_order", nargs="?", help="Job input json file")
@@ -884,7 +938,15 @@ def generate_parser(
         description = inp.get("doc", "")
         default = inp.get("default", None)
         add_argument(
-            toolparser, name, inptype, records, description, default, input_required
+            toolparser,
+            name,
+            inptype,
+            records,
+            description,
+            default,
+            input_required,
+            urljoin,
+            base_uri,
         )
 
     return toolparser
