@@ -1,25 +1,17 @@
 """Shared context objects that replace use of kwargs."""
 import copy
 import os
+import shutil
 import tempfile
 import threading
-from typing import (
-    IO,
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    TextIO,
-    Union,
-)
+from typing import IO, Any, Callable, Dict, Iterable, List, Optional, TextIO, Union
 
+# move to a regular typing import when Python 3.3-3.6 is no longer supported
 from ruamel.yaml.comments import CommentedMap
 from schema_salad.avro.schema import Names
 from schema_salad.ref_resolver import Loader
 from schema_salad.utils import FetcherCallableType
+from typing_extensions import TYPE_CHECKING
 
 from .builder import Builder
 from .mpi import MpiConfig
@@ -56,6 +48,30 @@ def make_tool_notimpl(
 default_make_tool = make_tool_notimpl
 
 
+def log_handler(
+    outdir: str,
+    base_path_logs: str,
+    stdout_path: Optional[str],
+    stderr_path: Optional[str],
+) -> None:
+    """Move logs from log location to final output."""
+    if outdir != base_path_logs:
+        if stdout_path:
+            new_stdout_path = stdout_path.replace(base_path_logs, outdir)
+            shutil.copy2(stdout_path, new_stdout_path)
+        if stderr_path:
+            new_stderr_path = stderr_path.replace(base_path_logs, outdir)
+            shutil.copy2(stderr_path, new_stderr_path)
+
+
+def set_log_dir(outdir: str, log_dir: str, subdir_name: str) -> str:
+    """Default handler for setting the log directory."""
+    if log_dir == "":
+        return outdir
+    else:
+        return log_dir + "/" + subdir_name
+
+
 class LoadingContext(ContextBase):
     def __init__(self, kwargs: Optional[Dict[str, Any]] = None) -> None:
         """Initialize the LoadingContext from the kwargs."""
@@ -118,6 +134,9 @@ class RuntimeContext(ContextBase):
         self.pull_image = True  # type: bool
         self.rm_container = True  # type: bool
         self.move_outputs = "move"  # type: str
+        self.log_dir = ""  # type: str
+        self.set_log_dir = set_log_dir
+        self.log_dir_handler = log_handler
         self.streaming_allowed: bool = False
 
         self.singularity = False  # type: bool
