@@ -1,8 +1,15 @@
 import subprocess
 import time
-
+import pkg_resources
 from setuptools.command.egg_info import egg_info
 
+SETUPTOOLS_VER = pkg_resources.get_distribution(
+    "setuptools").version.split('.')
+
+RECENT_SETUPTOOLS = int(SETUPTOOLS_VER[0]) > 40 or (
+    int(SETUPTOOLS_VER[0]) == 40 and int(SETUPTOOLS_VER[1]) > 0) or (
+        int(SETUPTOOLS_VER[0]) == 40 and int(SETUPTOOLS_VER[1]) == 0 and
+        int(SETUPTOOLS_VER[2]) > 0)
 
 class EggInfoFromGit(egg_info):
     """Tag the build with git commit timestamp.
@@ -24,3 +31,6 @@ class EggInfoFromGit(egg_info):
             except subprocess.CalledProcessError:
                 pass
         return egg_info.tags(self)
+
+    if RECENT_SETUPTOOLS:
+        vtags = property(tags)
