@@ -512,6 +512,53 @@ def test_scandeps() -> None:
     assert scanned_deps2 == expected_deps
 
 
+def test_scandeps_samedirname() -> None:
+    obj: CWLObjectType = {
+        "dir1": {"class": "Directory", "location": "tests/wf/dir1/foo"},
+        "dir2": {"class": "Directory", "location": "tests/wf/dir2/foo"},
+    }
+
+    def loadref(
+        base: str, p: Union[CommentedMap, CommentedSeq, str, None]
+    ) -> Union[CommentedMap, CommentedSeq, str, None]:
+        if isinstance(p, dict):
+            return p
+        raise Exception("test case can't load things")
+
+    scanned_deps = cast(
+        List[Dict[str, Any]],
+        cwltool.process.scandeps(
+            "",
+            obj,
+            {"$import", "run"},
+            {"$include", "$schemas", "location"},
+            loadref,
+            nestdirs=False,
+        ),
+    )
+
+    scanned_deps.sort(key=lambda k: cast(str, k["basename"]))
+
+    expected_deps = [
+        {"basename": "foo", "class": "Directory", "location": "tests/wf/dir1/foo"},
+        {"basename": "foo", "class": "Directory", "location": "tests/wf/dir2/foo"},
+    ]
+
+    assert scanned_deps == expected_deps
+
+
+def test_scandeps_collision() -> None:
+    stream = StringIO()
+
+    assert (
+        main(
+            ["--print-deps", "--debug", get_data("tests/wf/dir_deps.json")],
+            stdout=stream,
+        )
+        == 1
+    )
+
+
 def test_trick_scandeps() -> None:
     stream = StringIO()
 
@@ -827,6 +874,26 @@ def test_format_expr_error() -> None:
     )
 
 
+def test_format_expr_error2() -> None:
+    """Better format expression error, for a list of formats."""
+    error_code, _, stderr = get_main_output(
+        [
+            get_data("tests/wf/bad_formattest2.cwl"),
+            get_data("tests/wf/formattest-job.json"),
+        ]
+    )
+    assert error_code != 0
+    stderr = re.sub(r"\s\s+", " ", stderr)
+    assert (
+        "bad_formattest2.cwl:14:9: For inputs, 'format' field can either contain "
+        "a single CWL Expression or CWL Parameter Reference, a single format string, "
+        "or a list of format strings. But the list cannot contain CWL Expressions "
+        "or CWL Parameter References. List entry number 1 contains the following "
+        "unallowed CWL Parameter Reference or Expression: '${ return "
+        '["http://edamontology.org/format_2330", 42];}' in stderr
+    )
+
+
 def test_static_checker() -> None:
     # check that the static checker raises exception when a source type
     # mismatches its sink type.
@@ -1618,3 +1685,59 @@ def test_command_line_tool_class() -> None:
     tool_path = get_data("tests/echo.cwl")
     expression_tool = factory.make(tool_path).t
     assert str(expression_tool) == f"CommandLineTool: file://{tool_path}"
+
+
+def test_record_default_with_long() -> None:
+    """Confirm that record defaults are respected."""
+    tool_path = get_data("tests/wf/paramref_arguments_roundtrip.cwl")
+    err_code, stdout, stderr = get_main_output([tool_path])
+    assert err_code == 0
+    result = json.loads(stdout)["same_record"]
+    assert result["first"] == "y"
+    assert result["second"] == 23
+    assert result["third"] == 2.3
+    assert result["fourth"] == 4242424242
+    assert result["fifth"] == 4200000000000000000000000000000000000000000
+    assert result["sixth"]["class"] == "File"
+    assert result["sixth"]["basename"] == "whale.txt"
+    assert result["sixth"]["size"] == 1111
+    assert (
+        result["sixth"]["checksum"] == "sha1$327fc7aedf4f6b69a42a7c8b808dc5a7aff61376"
+    )
+
+
+def test_record_outputeval() -> None:
+    """Confirm that record types can be populated from outputEval."""
+    tool_path = get_data("tests/wf/record_outputeval.cwl")
+    err_code, stdout, stderr = get_main_output([tool_path])
+    assert err_code == 0
+    result = json.loads(stdout)["references"]
+    assert "genome_fa" in result
+    assert result["genome_fa"]["class"] == "File"
+    assert result["genome_fa"]["basename"] == "GRCm38.primary_assembly.genome.fa"
+    assert (
+        result["genome_fa"]["checksum"]
+        == "sha1$da39a3ee5e6b4b0d3255bfef95601890afd80709"
+    )
+    assert result["genome_fa"]["size"] == 0
+    assert "annotation_gtf" in result
+    assert result["annotation_gtf"]["class"] == "File"
+    assert (
+        result["annotation_gtf"]["basename"]
+        == "gencode.vM21.primary_assembly.annotation.gtf"
+    )
+    assert (
+        result["annotation_gtf"]["checksum"]
+        == "sha1$da39a3ee5e6b4b0d3255bfef95601890afd80709"
+    )
+    assert result["annotation_gtf"]["size"] == 0
+
+
+def tests_outputsource_valid_identifier_invalid_source() -> None:
+    """Confirm error for invalid source that was also a valid identifier."""
+    tool_path = get_data("tests/checker_wf/broken-wf4.cwl")
+    err_code, stdout, stderr = get_main_output([tool_path])
+    assert err_code == 1
+    stderr = re.sub(r"\s\s+", " ", stderr)
+    assert "tests/checker_wf/broken-wf4.cwl:12:5: outputSource not found" in stderr
+    assert "tests/checker_wf/broken-wf4.cwl#echo_w" in stderr
