@@ -1,14 +1,14 @@
 import json
 import os
 import tempfile
+from collections.abc import Sized
 from functools import partial
 from io import StringIO
-from tempfile import NamedTemporaryFile
+from pathlib import Path
 from typing import Dict
 
-import py.path
-import pytest  # type: ignore
-from ruamel import yaml
+import pytest
+from schema_salad.utils import yaml_no_ts
 
 import cwltool.pack
 import cwltool.workflow
@@ -21,51 +21,48 @@ from cwltool.utils import adjustDirObjs, adjustFileObjs
 from .util import get_data, needs_docker
 
 
-def test_pack() -> None:
-    loadingContext, workflowobj, uri = fetch_document(get_data("tests/wf/revsort.cwl"))
-
-    with open(get_data("tests/wf/expect_packed.cwl")) as packed_file:
-        expect_packed = yaml.main.safe_load(packed_file)
-
-    packed = cwltool.pack.pack(loadingContext, uri)
-    adjustFileObjs(
-        packed, partial(make_relative, os.path.abspath(get_data("tests/wf")))
-    )
-    adjustDirObjs(packed, partial(make_relative, os.path.abspath(get_data("tests/wf"))))
-
-    assert "$schemas" in packed
-    assert len(packed["$schemas"]) == len(expect_packed["$schemas"])
-    del packed["$schemas"]
-    del expect_packed["$schemas"]
-
-    assert packed == expect_packed
-
-
-def test_pack_input_named_name() -> None:
-    loadingContext, workflowobj, uri = fetch_document(
-        get_data("tests/wf/trick_revsort.cwl")
-    )
+@pytest.mark.parametrize(
+    "unpacked,expected",
+    [
+        ("tests/wf/revsort.cwl", "tests/wf/expect_packed.cwl"),
+        (
+            "tests/wf/operation/operation-single.cwl",
+            "tests/wf/operation/expect_operation-single_packed.cwl",
+        ),
+        ("tests/wf/trick_revsort.cwl", "tests/wf/expect_trick_packed.cwl"),
+        (
+            "tests/wf/iwd-passthrough1.cwl",
+            "tests/wf/expect_iwd-passthrough1_packed.cwl",
+        ),
+        (
+            "tests/wf/revsort_datetime.cwl",
+            "tests/wf/expect_revsort_datetime_packed.cwl",
+        ),
+    ],
+)
+def test_packing(unpacked: str, expected: str) -> None:
+    """Compare expected version reality with various workflows and --pack."""
+    loadingContext, workflowobj, uri = fetch_document(get_data(unpacked))
     loadingContext.do_update = False
     loadingContext, uri = resolve_and_validate_document(
         loadingContext, workflowobj, uri
     )
-    loader = loadingContext.loader
-    assert loader
-    loader.resolve_ref(uri)[0]
 
-    with open(get_data("tests/wf/expect_trick_packed.cwl")) as packed_file:
-        expect_packed = yaml.main.round_trip_load(packed_file)
+    packed = json.loads(print_pack(loadingContext, uri))
+    context_dir = os.path.abspath(os.path.dirname(get_data(unpacked)))
+    adjustFileObjs(packed, partial(make_relative, context_dir))
+    adjustDirObjs(packed, partial(make_relative, context_dir))
 
-    packed = cwltool.pack.pack(loadingContext, uri)
-    adjustFileObjs(
-        packed, partial(make_relative, os.path.abspath(get_data("tests/wf")))
-    )
-    adjustDirObjs(packed, partial(make_relative, os.path.abspath(get_data("tests/wf"))))
+    with open(get_data(expected)) as packed_file:
+        expect_packed = json.load(packed_file)
 
-    assert "$schemas" in packed
-    assert len(packed["$schemas"]) == len(expect_packed["$schemas"])
-    del packed["$schemas"]
-    del expect_packed["$schemas"]
+    if "$schemas" in expect_packed:
+        assert "$schemas" in packed
+        packed_schemas = packed["$schemas"]
+        assert isinstance(packed_schemas, Sized)
+        assert len(packed_schemas) == len(expect_packed["$schemas"])
+        del packed["$schemas"]
+        del expect_packed["$schemas"]
 
     assert packed == expect_packed
 
@@ -87,8 +84,10 @@ def test_pack_single_tool() -> None:
 
 
 def test_pack_fragment() -> None:
+    yaml = yaml_no_ts()
+
     with open(get_data("tests/wf/scatter2_subwf.cwl")) as packed_file:
-        expect_packed = yaml.main.safe_load(packed_file)
+        expect_packed = yaml.load(packed_file)
 
     loadingContext, workflowobj, uri = fetch_document(get_data("tests/wf/scatter2.cwl"))
     packed = cwltool.pack.pack(loadingContext, uri + "#scatterstep/mysub")
@@ -97,9 +96,10 @@ def test_pack_fragment() -> None:
     )
     adjustDirObjs(packed, partial(make_relative, os.path.abspath(get_data("tests/wf"))))
 
-    assert json.dumps(packed, sort_keys=True, indent=2) == json.dumps(
-        expect_packed, sort_keys=True, indent=2
-    )
+    packed_result = json.dumps(packed, sort_keys=True, indent=2)
+    expected = json.dumps(expect_packed, sort_keys=True, indent=2)
+
+    assert packed_result == expected
 
 
 def test_pack_rewrites() -> None:
@@ -117,7 +117,9 @@ def test_pack_rewrites() -> None:
     loader.resolve_ref(uri)[0]
 
     cwltool.pack.pack(
-        loadingContext, uri, rewrite_out=rewrites,
+        loadingContext,
+        uri,
+        rewrite_out=rewrites,
     )
 
     assert len(rewrites) == 6
@@ -129,7 +131,7 @@ cwl_missing_version_paths = [
 ]
 
 
-@pytest.mark.parametrize("cwl_path", cwl_missing_version_paths)  # type: ignore
+@pytest.mark.parametrize("cwl_path", cwl_missing_version_paths)
 def test_pack_missing_cwlVersion(cwl_path: str) -> None:
     """Ensure the generated pack output is not missing the `cwlVersion` in case of single tool workflow and single step workflow."""
     # Testing single tool workflow
@@ -148,17 +150,17 @@ def test_pack_missing_cwlVersion(cwl_path: str) -> None:
     assert packed["cwlVersion"] == "v1.0"
 
 
-def test_pack_idempotence_tool() -> None:
+def test_pack_idempotence_tool(tmp_path: Path) -> None:
     """Ensure that pack produces exactly the same document for an already packed CommandLineTool."""
-    _pack_idempotently("tests/wf/hello_single_tool.cwl")
+    _pack_idempotently("tests/wf/hello_single_tool.cwl", tmp_path)
 
 
-def test_pack_idempotence_workflow() -> None:
+def test_pack_idempotence_workflow(tmp_path: Path) -> None:
     """Ensure that pack produces exactly the same document for an already packed workflow."""
-    _pack_idempotently("tests/wf/count-lines1-wf.cwl")
+    _pack_idempotently("tests/wf/count-lines1-wf.cwl", tmp_path)
 
 
-def _pack_idempotently(document: str) -> None:
+def _pack_idempotently(document: str, tmp_path: Path) -> None:
     loadingContext, workflowobj, uri = fetch_document(get_data(document))
     loadingContext.do_update = False
     loadingContext, uri = resolve_and_validate_document(
@@ -172,26 +174,24 @@ def _pack_idempotently(document: str) -> None:
     packed_text = print_pack(loadingContext, uri)
     packed = json.loads(packed_text)
 
-    tmp = NamedTemporaryFile(mode="w", delete=False)
-    try:
-        tmp.write(packed_text)
-        tmp.flush()
-        tmp.close()
+    tmp_name = tmp_path / "packed.cwl"
+    tmp = tmp_name.open(mode="w")
+    tmp.write(packed_text)
+    tmp.flush()
+    tmp.close()
 
-        loadingContext, workflowobj, uri2 = fetch_document(tmp.name)
-        loadingContext.do_update = False
-        loadingContext, uri2 = resolve_and_validate_document(
-            loadingContext, workflowobj, uri2
-        )
-        loader2 = loadingContext.loader
-        assert loader2
-        loader2.resolve_ref(uri2)[0]
+    loadingContext, workflowobj, uri2 = fetch_document(tmp.name)
+    loadingContext.do_update = False
+    loadingContext, uri2 = resolve_and_validate_document(
+        loadingContext, workflowobj, uri2
+    )
+    loader2 = loadingContext.loader
+    assert loader2
+    loader2.resolve_ref(uri2)[0]
 
-        # generate pack output dict
-        packed_text = print_pack(loadingContext, uri2)
-        double_packed = json.loads(packed_text)
-    finally:
-        os.remove(tmp.name)
+    # generate pack output dict
+    packed_text = print_pack(loadingContext, uri2)
+    double_packed = json.loads(packed_text)
 
     assert uri != uri2
     assert packed == double_packed
@@ -203,10 +203,10 @@ cwl_to_run = [
 ]
 
 
-@needs_docker  # type: ignore
-@pytest.mark.parametrize("wf_path,job_path,namespaced", cwl_to_run)  # type: ignore
+@needs_docker
+@pytest.mark.parametrize("wf_path,job_path,namespaced", cwl_to_run)
 def test_packed_workflow_execution(
-    wf_path: str, job_path: str, namespaced: bool, tmpdir: py.path.local
+    wf_path: str, job_path: str, namespaced: bool, tmp_path: Path
 ) -> None:
     loadingContext = LoadingContext()
     loadingContext.resolver = tool_resolver
@@ -229,10 +229,10 @@ def test_packed_workflow_execution(
     normal_output = StringIO()
     packed_output = StringIO()
 
-    normal_params = ["--outdir", str(tmpdir), get_data(wf_path), get_data(job_path)]
+    normal_params = ["--outdir", str(tmp_path), get_data(wf_path), get_data(job_path)]
     packed_params = [
         "--outdir",
-        str(tmpdir),
+        str(tmp_path),
         "--debug",
         wf_packed_path,
         get_data(job_path),
