@@ -9,7 +9,7 @@ from cwltool.load_tool import load_tool
 from cwltool.subgraph import get_step, get_subgraph
 from cwltool.workflow import Workflow, default_make_tool
 
-from .util import get_data, get_main_output
+from .util import get_data, get_main_output, needs_docker
 
 
 def clean(val: Any, path: str) -> Any:
@@ -224,6 +224,23 @@ def test_single_process_packed_subwf_step() -> None:
     )
 
 
+def test_single_process_subwf_subwf_inline_step() -> None:
+    """Test --single-process on an inline sub-sub-workflow step."""
+    err_code, stdout, stderr = get_main_output(
+        [
+            "--single-process",
+            "step1/stepX/stepY",
+            get_data("tests/subgraph/count-lines17-wf.cwl.json"),
+            get_data("tests/wf/wc-job.json"),
+        ]
+    )
+    assert err_code == 0
+    assert (
+        json.loads(stdout)["output"]["checksum"]
+        == "sha1$3596ea087bfdaf52380eae441077572ed289d657"
+    )
+
+
 def test_single_step_subwf_step() -> None:
     """Inherit reqs and hints --single-step on sub-workflow step."""
     err_code, stdout, stderr = get_main_output(
@@ -241,6 +258,23 @@ def test_single_step_subwf_step() -> None:
     )
 
 
+def test_single_step_wfstep_long_out() -> None:
+    """Support long form of step.out with --single-step."""
+    err_code, stdout, stderr = get_main_output(
+        [
+            "--single-step",
+            "sub_wf/step1",
+            get_data("tests/subgraph/env-wf2_subwf_b.cwl"),
+            get_data("tests/subgraph/env-job.json"),
+        ]
+    )
+    assert err_code == 0
+    assert (
+        json.loads(stdout)["out"]["checksum"]
+        == "sha1$7608e5669ba454c61fab01c9b133b52a9a7de68c"
+    )
+
+
 def test_single_step_packed_subwf_step() -> None:
     """Inherit reqs and hints --single-step on packed sub-workflow step."""
     err_code, stdout, stderr = get_main_output(
@@ -258,6 +292,20 @@ def test_single_step_packed_subwf_step() -> None:
     )
 
 
+@needs_docker
+def test_single_with_step_level_default_value() -> None:
+    """Inherit step-level defaults with --single-step."""
+    err_code, stdout, stderr = get_main_output(
+        [
+            "--single-step",
+            "task2",
+            get_data("tests/wf/cache_test_workflow.cwl"),
+        ]
+    )
+    assert err_code == 0
+    assert "two" in stderr
+
+
 def test_print_targets_embedded_step() -> None:
     """Confirm that --print-targets works when a Workflow has embedded Processes."""
     err_code, stdout, stderr = get_main_output(
@@ -278,3 +326,15 @@ def test_print_targets_embedded_reqsinherit() -> None:
         ]
     )
     assert err_code == 0
+
+
+def test_print_targets_embedded_sub_subwfs() -> None:
+    """Confirm that --print-targets works with inline sub-sub-workflows."""
+    err_code, stdout, stderr = get_main_output(
+        [
+            "--print-targets",
+            get_data("tests/subgraph/count-lines17-wf.cwl.json"),
+        ]
+    )
+    assert err_code == 0
+    assert "step1/stepX/stepY" in stdout
